# chobo

The chobo module is a forked version of the [intrographics](http://myslu.stlawu.edu/~ltorrey/intrographics/) module developed by [Dr. Lisa Torrey](http://myslu.stlawu.edu/~ltorrey/).

It allows you to create graphical displays in your Python 3 programs.
The name chobo (초보) is a Korean word that means a beginner/novice, and the name is to inspire beginners at programming to give it a try.

It is written in [Python 3](https://www.python.org/), and uses the [pygame](https://www.pygame.org/) module as the back-end, and adds the following features:

* Image files other than just GIF
* Arc as a new shape
* An empty image shape
* Shape rotations
* Use of any system fonts
* Sound/music files and their playback

The full documentation is available in the [doc](https://github.com/choongsoo/chobo/tree/master/doc) folder.